@@ -32,6 +32,7 @@ mod authorizer;
 mod config;
 mod log_metadata;
 mod log_records;
+use authorizer::Authorizer;
 use log_metadata::LogMetadataImpl;
 use log_records::LogRecordsImpl;
 
@@ -43,6 +44,8 @@ async fn main() -> Result<(), Box<dyn Error>> {
 
     configure_logging(&config.logging)?;
 
+    let authorizer = Authorizer::new().await?;
+
     let (_, agent_health_service) = tonic_health::server::health_reporter();
     let reflection_service = tonic_reflection::server::Builder::configure()
         .register_encoded_file_descriptor_set(FILE_DESCRIPTOR_SET)
@@ -61,11 +64,13 @@ async fn main() -> Result<(), Box<dyn Error>> {
             root_ctx.clone(),
             task_tracker.clone(),
             config.logs_dir.clone(),
+            authorizer.clone(),
         )))
         .add_service(LogRecordsServiceServer::new(LogRecordsImpl::new(
             root_ctx.clone(),
             task_tracker.clone(),
             config.logs_dir.clone(),
+            authorizer.clone(),
         )))
         .serve_with_shutdown(config.address, shutdown(root_ctx))
         .await?;
